
CREATE OR REPLACE VIEW public.adhoc_apps_spermissions_v AS 
 SELECT suser_account_permission.suser,
    suser_account_permission.saccount,
    data_source.id AS application_id,
    data_source.name AS application_name,
    data_source.description AS application_description,
    application.risk AS application_risk,
    spermission.id AS permission_id,
    spermission.name AS permission_name,
    spermission.description AS permission_description,
    spermission.risk AS permission_risk,
    spermission.type AS permission_type,
    max(review_instance.end_date) AS last_certification,
        CASE
            WHEN max(review_instance.end_date) IS NOT NULL THEN true
            ELSE false
        END AS is_certified,
        CASE
            WHEN certified.review_status::text <> 'CERTIFIED'::text AND certified.user_id IS NOT NULL THEN true
            ELSE false
        END AS certification_pending
   FROM suser_account_permission
     LEFT JOIN spermission ON suser_account_permission.spermission = spermission.id
     LEFT JOIN application ON spermission.application = application.id
     LEFT JOIN data_source ON application.id = data_source.id
     LEFT JOIN review_item_status_v certified ON suser_account_permission.suser = certified.user_id AND spermission.id = certified.permission_id
     LEFT JOIN review_instance ON certified.review_instance_id = review_instance.id
  WHERE spermission.deleted = false AND spermission.effective = true AND data_source.data_source_type::text = 'APPLICATION'::text AND data_source.deleted = false
  GROUP BY suser_account_permission.suser, suser_account_permission.saccount, data_source.id, data_source.name, data_source.description, application.risk, spermission.id, spermission.name, spermission.description, spermission.risk, spermission.type, certified.review_status, certified.user_id;


ALTER TABLE public.adhoc_apps_spermissions_v
  OWNER TO igops;
GRANT ALL ON TABLE public.adhoc_apps_spermissions_v TO igops;
GRANT SELECT ON TABLE public.adhoc_apps_spermissions_v TO ig_report_role;